🧑‍🍳 Cook
==========

.. image:: https://github.com/tillahoffmann/cook-build/actions/workflows/main.yaml/badge.svg
    :target: https://github.com/tillahoffmann/cook-build/actions/workflows/main.yaml

Cook is a task-centric build system. Each task is a pure operation that receives any number of files as input and produces one or more outputs. Tasks without outputs are special and will always be executed.
